pub enum BootstrapBlockRoot {
DiskImage {
device: String,
fstype: Option<String>,
},
OciErofs {
lower: String,
upper: BootstrapBlockRootUpper,
},
}Expand description
Block-backed root filesystem configuration.
Variants
DiskImage
A single filesystem image mounted as the guest root.
Fields
OciErofs
An EROFS lower filesystem combined with a writable overlay upper.
Fields

upper: BootstrapBlockRootUpperWritable overlay backing.