BulkSendState

Struct BulkSendState 

pub struct BulkSendState { /* private fields */ }
Sender-side absolute-offset and credit state for one flow.

Implementations

Source

impl BulkSendState

pub fn new( kind: BulkKind, flow: BulkFlow, max_record_payload: u32, credit_limit: u64, ) -> Result<Self, BulkStateError>

Create one sender flow from negotiated limits.

pub fn next_offset(&self) -> u64

Return the next byte offset this sender will assign.

pub fn credit_limit(&self) -> u64

Return the currently admitted exclusive limit.

pub fn max_record_payload(&self) -> u32

Return the maximum payload negotiated for this flow.

pub fn available_credit(&self) -> u64

Return bytes the sender may currently admit without another credit update.

pub fn admit(&mut self, payload_len: usize) -> Result<u64, BulkStateError>

Admit a payload and advance the ordered sender cursor.

pub fn apply_credit( &mut self, credit: BulkCredit, ) -> Result<bool, BulkStateError>

Apply one idempotent absolute credit update.

pub fn finish(&mut self) -> Result<BulkFinish, BulkStateError>

Finish this sender at its exact current offset.