pub fn raw_frame_to_bulk(
frame: RawFrame,
max_payload: u32,
) -> ProtocolResult<BulkRecord>Expand description
Decodes and validates a raw frame as a generation-8 bulk record.
pub fn raw_frame_to_bulk(
frame: RawFrame,
max_payload: u32,
) -> ProtocolResult<BulkRecord>Decodes and validates a raw frame as a generation-8 bulk record.