try_decode_raw_from_buf

Function try_decode_raw_from_buf 

pub fn try_decode_raw_from_buf(
    buf: &mut Vec<u8>,
) -> ProtocolResult<Option<RawFrame>>
Tries to decode a complete raw frame from a byte buffer.

Returns Some(RawFrame) if a complete frame is available, consuming the bytes. Returns None if more data is needed.

Frame format: [len: u32 BE][id: u32 BE][flags: u8][body...]