pub enum FsOp {
Show 19 variants
RealPath {
path: String,
},
Stat {
path: String,
follow_symlink: bool,
},
SetStat {
path: String,
follow_symlink: bool,
attrs: FsSetAttrs,
},
List {
path: String,
},
ReadLink {
path: String,
},
Symlink {
target: String,
link_path: String,
},
Mkdir {
path: String,
mode: Option<u32>,
},
Remove {
path: String,
},
RemoveDir {
path: String,
recursive: bool,
},
Copy {
src: String,
dst: String,
},
Rename {
src: String,
dst: String,
},
OpenFile {
path: String,
options: FsOpenOptions,
},
OpenDir {
path: String,
},
CloseHandle {
handle: u64,
},
Read {
handle: u64,
offset: u64,
len: Option<u64>,
},
Write {
handle: u64,
offset: u64,
len: Option<u64>,
},
ReadDir {
handle: u64,
limit: Option<u32>,
},
FStat {
handle: u64,
},
FSetStat {
handle: u64,
attrs: FsSetAttrs,
},
}Expand description
A filesystem operation requested by the host.
Variants
RealPath
Resolve a path to its canonical absolute form.
Stat
Get metadata for a path.
SetStat
Update metadata for a path.
Fields

attrs: FsSetAttrsAttributes to update.
List
List directory contents.
ReadLink
Read a symlink target.
Symlink
Create a symlink.
Mkdir
Create a directory (and parents).
Fields
Remove
Remove a file.
RemoveDir
Remove a directory.
Copy
Copy a file or directory within the guest.
Rename
Rename/move a file or directory.
OpenFile
Open a file and allocate an agentd-side handle.
OpenDir
Open a directory and allocate an agentd-side handle.
CloseHandle
Close a file or directory handle.
Read
Read from an open file handle.
Fields
Write
Write to an open file handle.
Fields
ReadDir
Read the next batch of entries from an open directory handle.
Fields
FStat
Get metadata for an open file or directory handle.
FSetStat
Update metadata for an open file handle.