Module message

Module message 

Message envelope and type definitions for the agent protocol.

Structs

Message
The message envelope sent over the wire.

Enums

MessageType
Identifies the type of a protocol message.

Constants

FLAG_SESSION_START
Frame flag: this is the first message of a new session.
FLAG_SHUTDOWN
Frame flag: this message requests sandbox shutdown.
FLAG_TERMINAL
Frame flag: this is the last message for the given correlation ID.
FRAME_HEADER_SIZE
Size of the frame header fields that sit between the length prefix and the CBOR payload: [id: u32 BE][flags: u8] = 5 bytes.
PROTOCOL_VERSION
Current protocol version.