Crate microsandbox_protocol

Crate microsandbox_protocol 

microsandbox-protocol defines the shared protocol types used for communication between the host and the guest agent over CBOR-over-virtio-serial.

Modules

codec
Length-prefixed CBOR frame codec for reading and writing protocol messages.
core
Core protocol message payloads.
exec
Exec-related protocol message payloads.
fs
Filesystem-related protocol message payloads.
heartbeat
Heartbeat data for the guest agent.
message
Message envelope and type definitions for the agent protocol.

Enums

ProtocolError
Errors that can occur during protocol operations.

Constants

AGENT_PORT_NAME
Virtio-console port name for the agent channel.
ENV_BLOCK_ROOT
Environment variable specifying the block device for rootfs switch.
ENV_NET
Environment variable carrying the guest network interface configuration.
ENV_NET_IPV4
Environment variable carrying the guest IPv4 network configuration.
ENV_NET_IPV6
Environment variable carrying the guest IPv6 network configuration.
ENV_TMPFS
Environment variable carrying tmpfs mount specs for guest init.
GUEST_TLS_CA_PATH
Guest-side path to the CA certificate for TLS interception.
RUNTIME_FS_TAG
Virtiofs tag for the runtime filesystem (scripts, heartbeat).
RUNTIME_MOUNT_POINT
Guest mount point for the runtime filesystem.

Type Aliases

ProtocolResult
The result type for protocol operations.