microsandbox-protocol defines the shared protocol types used for communication
between the host and the guest agent over CBOR-over-virtio-serial.
Modules
- codec
- Length-prefixed CBOR frame codec for reading and writing protocol messages.
- core
- Core protocol message payloads.
- exec
- Exec-related protocol message payloads.
- fs
- Filesystem-related protocol message payloads.
- heartbeat
- Heartbeat data for the guest agent.
- message
- Message envelope and type definitions for the agent protocol.
Enums
- Protocol
Error - Errors that can occur during protocol operations.
Constants
- AGENT_
PORT_ NAME - Virtio-console port name for the agent channel.
- ENV_
BLOCK_ ROOT - Environment variable specifying the block device for rootfs switch.
- ENV_NET
- Environment variable carrying the guest network interface configuration.
- ENV_
NET_ IPV4 - Environment variable carrying the guest IPv4 network configuration.
- ENV_
NET_ IPV6 - Environment variable carrying the guest IPv6 network configuration.
- ENV_
TMPFS - Environment variable carrying tmpfs mount specs for guest init.
- GUEST_
TLS_ CA_ PATH - Guest-side path to the CA certificate for TLS interception.
- RUNTIME_
FS_ TAG - Virtiofs tag for the runtime filesystem (scripts, heartbeat).
- RUNTIME_
MOUNT_ POINT - Guest mount point for the runtime filesystem.
Type Aliases
- Protocol
Result - The result type for protocol operations.