Length-prefixed CBOR frame codec for reading and writing protocol messages.
Constants
- MAX_
FRAME_ SIZE - Maximum allowed frame size (4 MiB).
Functions
- encode_
to_ buf - Encodes a message to a byte buffer using the length-prefixed frame format.
- read_
message - Reads a length-prefixed CBOR message from the given reader.
- try_
decode_ from_ buf - Tries to decode a complete message from a byte buffer.
- write_
message - Writes a length-prefixed CBOR message to the given writer.