Module exec

Module exec 

Exec-related protocol message payloads.

Structs

ExecExited
Notification that a command has exited.
ExecRequest
Request to execute a command in the guest.
ExecResize
Request to resize the PTY of a running command.
ExecRlimit
A POSIX resource limit to apply to a spawned process.
ExecSignal
Request to send a signal to a running command.
ExecStarted
Confirmation that a command has been started.
ExecStderr
Stderr data from a running command.
ExecStdin
Stdin data sent to a running command.
ExecStdout
Stdout data from a running command.