Exec-related protocol message payloads.
Structs
- Exec
Exited - Notification that a command has exited.
- Exec
Request - Request to execute a command in the guest.
- Exec
Resize - Request to resize the PTY of a running command.
- Exec
Rlimit - A POSIX resource limit to apply to a spawned process.
- Exec
Signal - Request to send a signal to a running command.
- Exec
Started - Confirmation that a command has been started.
- Exec
Stderr - Stderr data from a running command.
- Exec
Stdin - Stdin data sent to a running command.
- Exec
Stdout - Stdout data from a running command.