pub struct ExecRlimit {
pub resource: String,
pub soft: u64,
pub hard: u64,
}Expand description
A POSIX resource limit to apply to a spawned process.
Fields
resource: StringResource name (lowercase): “nofile”, “nproc”, “as”, “cpu”, etc.
soft: u64Soft limit (can be raised up to hard limit by the process).
hard: u64Hard limit (ceiling, requires privileges to raise).