Filesystem-related protocol message payloads.
Structs
- FsData
- A chunk of file data for streaming read/write operations.
- FsEntry
Info - Metadata about a filesystem entry (wire format).
- FsRequest
- Request to perform a filesystem operation in the guest.
- FsResponse
- Terminal response for a filesystem operation.
Enums
- FsOp
- A filesystem operation requested by the host.
- FsResponse
Data - Data variants that can be included in a filesystem response.
Constants
- FS_
CHUNK_ SIZE - Maximum chunk size for streaming file data (3 MiB).