Module fs

Module fs 

Filesystem-related protocol message payloads.

Structs

FsData
A chunk of file data for streaming read/write operations.
FsEntryInfo
Metadata about a filesystem entry (wire format).
FsOpenOptions
Options used when opening a file handle.
FsRequest
Request to perform a filesystem operation in the guest.
FsResponse
Terminal response for a filesystem operation.
FsSetAttrs
Attributes accepted by setstat-style filesystem operations.

Enums

FsOp
A filesystem operation requested by the host.
FsResponseData
Data variants that can be included in a filesystem response.

Constants

FS_CHUNK_SIZE
Maximum chunk size for streaming file data (3 MiB).