Message envelope and type definitions for the agent protocol.
Structs
- Message
- The message envelope sent over the wire.
Enums
- Message
Type - Identifies the type of a protocol message.
Constants
- FLAG_
SESSION_ START - Frame flag: this is the first message of a new session.
- FLAG_
SHUTDOWN - Frame flag: this message requests sandbox shutdown.
- FLAG_
TERMINAL - Frame flag: this is the last message for the given correlation ID.
- FRAME_
HEADER_ SIZE - Size of the frame header fields that sit between the length prefix and the
CBOR payload:
[id: u32 BE][flags: u8]= 5 bytes. - PROTOCOL_
VERSION - Current protocol version.